@@ -131,7 +131,7 @@ fi
 # Fetch VLC source #
 ####################
 
-TESTED_HASH=ed96e80
+TESTED_HASH=7740747
 if [ ! -d "vlc" ]; then
     echo "VLC source not found, cloning"
     git clone git://git.videolan.org/vlc.git vlc
@@ -217,3 +217,15 @@ if [ "$RUN" = 1 ]; then
         adb shell am start -n org.videolan.vlc.debug/org.videolan.vlc.gui.MainActivity
     fi
 fi
+
+#########################
+# Chrome OS repackaging #
+#########################
+# You need to run the armv7 version first, then relaunch this script for x86
+if [ "$CHROME_OS" = 1 -a "$ANDROID_ABI" = "x86" ]; then
+    unzip -o vlc-android/build/outputs/apk/VLC-Android-CHROME-*-ARMv7.apk lib/armeabi-v7a/libvlcjni.so
+    zip -rv vlc-android/build/outputs/apk/VLC-Android-CHROME-*-x86.apk lib/armeabi-v7a/libvlcjni.so
+    rm -rf lib/
+    apk_to_crx.py --zip vlc-android/build/outputs/apk/VLC-Android-CHROME-*-x86.apk --metadata vlc-android/flavors/chrome/VLC-Android-CHROME.crx.json
+    mv vlc-android/build/outputs/apk/VLC-Android-CHROME-*-x86.zip vlc-android/build/outputs/apk/VLC-Android-CHROME-ALL.zip
+fi
