@@ -20,6 +20,7 @@
 
 package org.videolan.vlc.gui.audio;
 
+import android.Manifest;
 import android.content.Context;
 import android.content.Intent;
 import android.content.SharedPreferences;
@@ -27,22 +28,19 @@ import android.media.AudioManager;
 import android.os.Bundle;
 import android.os.Handler;
 import android.preference.PreferenceManager;
+import android.support.annotation.RequiresPermission;
 import android.support.design.widget.Snackbar;
 import android.support.v4.app.FragmentActivity;
 import android.support.v4.app.FragmentManager;
-import android.util.Log;
-import android.view.ContextMenu;
-import android.view.ContextMenu.ContextMenuInfo;
+import android.support.v7.widget.LinearLayoutManager;
+import android.support.v7.widget.PopupMenu;
+import android.support.v7.widget.RecyclerView;
+import android.support.v7.widget.helper.ItemTouchHelper;
 import android.view.LayoutInflater;
-import android.view.MenuInflater;
 import android.view.MenuItem;
 import android.view.MotionEvent;
 import android.view.View;
 import android.view.ViewGroup;
-import android.widget.AdapterView;
-import android.widget.AdapterView.AdapterContextMenuInfo;
-import android.widget.AdapterView.OnItemClickListener;
-import android.widget.AdapterView.OnItemLongClickListener;
 import android.widget.ImageButton;
 import android.widget.ProgressBar;
 import android.widget.SeekBar;
@@ -52,20 +50,22 @@ import android.widget.ViewSwitcher;
 
 import org.videolan.libvlc.Media;
 import org.videolan.libvlc.MediaPlayer;
-import org.videolan.vlc.MediaWrapper;
+import org.videolan.vlc.gui.helpers.UiTools;
+import org.videolan.vlc.media.MediaWrapper;
 import org.videolan.vlc.PlaybackService;
 import org.videolan.vlc.R;
 import org.videolan.vlc.VLCApplication;
 import org.videolan.vlc.gui.AudioPlayerContainerActivity;
 import org.videolan.vlc.gui.PlaybackServiceFragment;
-import org.videolan.vlc.gui.preferences.PreferencesActivity;
-import org.videolan.vlc.gui.audio.widget.CoverMediaSwitcher;
-import org.videolan.vlc.gui.audio.widget.HeaderMediaSwitcher;
+import org.videolan.vlc.gui.helpers.SwipeDragItemTouchHelperCallback;
+import org.videolan.vlc.gui.view.CoverMediaSwitcher;
+import org.videolan.vlc.gui.view.HeaderMediaSwitcher;
 import org.videolan.vlc.gui.dialogs.AdvOptionsDialog;
 import org.videolan.vlc.gui.dialogs.SavePlaylistDialog;
+import org.videolan.vlc.gui.preferences.PreferencesActivity;
 import org.videolan.vlc.util.Strings;
 import org.videolan.vlc.util.Util;
-import org.videolan.vlc.widget.AudioMediaSwitcher.AudioMediaSwitcherListener;
+import org.videolan.vlc.gui.view.AudioMediaSwitcher.AudioMediaSwitcherListener;
 
 import java.util.ArrayList;
 import java.util.List;
@@ -89,7 +89,7 @@ public class AudioPlayer extends PlaybackServiceFragment implements PlaybackServ
     private ImageButton mAdvFunc;
     private ImageButton mPlaylistSwitch, mPlaylistSave;
     private SeekBar mTimeline;
-    private AudioPlaylistView mSongsList;
+    private RecyclerView mSongsList;
 
     ViewSwitcher mSwitcher;
 
@@ -97,7 +97,7 @@ public class AudioPlayer extends PlaybackServiceFragment implements PlaybackServ
     private boolean mPreviewingSeek = false;
     private boolean mSwitchedToVideo = false;
 
-    private AudioPlaylistAdapter mSongsListAdapter;
+    private PlaylistAdapter mPlaylistAdapter;
 
     private boolean mAdvFuncVisible;
     private boolean mPlaylistSwitchVisible;
@@ -114,7 +114,7 @@ public class AudioPlayer extends PlaybackServiceFragment implements PlaybackServ
     public void onCreate(Bundle savedInstanceState) {
         super.onCreate(savedInstanceState);
 
-        mSongsListAdapter = new AudioPlaylistAdapter(getActivity());
+        mPlaylistAdapter = new PlaylistAdapter(this);
     }
 
     @Override
@@ -143,8 +143,15 @@ public class AudioPlayer extends PlaybackServiceFragment implements PlaybackServ
         mPlaylistSave = (ImageButton) v.findViewById(R.id.playlist_save);
         mTimeline = (SeekBar) v.findViewById(R.id.timeline);
 
-        mSongsList = (AudioPlaylistView) v.findViewById(R.id.songs_list);
-        mSongsList.setAdapter(mSongsListAdapter);
+        mSongsList = (RecyclerView) v.findViewById(R.id.songs_list);
+        final LinearLayoutManager layoutManager = new LinearLayoutManager(getActivity());
+        layoutManager.setOrientation(LinearLayoutManager.VERTICAL);
+        mSongsList.setLayoutManager(layoutManager);
+        mSongsList.setAdapter(mPlaylistAdapter);
+
+        ItemTouchHelper.Callback callback =  new SwipeDragItemTouchHelperCallback(mPlaylistAdapter);
+        ItemTouchHelper touchHelper = new ItemTouchHelper(callback);
+        touchHelper.attachToRecyclerView(mSongsList);
 
         mSwitcher = (ViewSwitcher) v.findViewById(R.id.view_switcher);
         mSwitcher.setInAnimation(getActivity(), android.R.anim.fade_in);
@@ -200,10 +207,10 @@ public class AudioPlayer extends PlaybackServiceFragment implements PlaybackServ
             }
         });
         mNext.setOnTouchListener(new LongSeekListener(true,
-                Util.getResourceFromAttribute(getActivity(), R.attr.ic_next),
+                UiTools.getResourceFromAttribute(getActivity(), R.attr.ic_next),
                 R.drawable.ic_next_pressed));
         mPrevious.setOnTouchListener(new LongSeekListener(false,
-                Util.getResourceFromAttribute(getActivity(), R.attr.ic_previous),
+                UiTools.getResourceFromAttribute(getActivity(), R.attr.ic_previous),
                 R.drawable.ic_previous_pressed));
         mShuffle.setOnClickListener(new View.OnClickListener() {
             @Override
@@ -229,42 +236,11 @@ public class AudioPlayer extends PlaybackServiceFragment implements PlaybackServ
             public void onClick(View v) {
                 mSwitcher.showNext();
                 if (mSwitcher.getDisplayedChild() == 0)
-                    mPlaylistSwitch.setImageResource(Util.getResourceFromAttribute(getActivity(),
-                                                     R.attr.ic_playlist_on));
+                    mPlaylistSwitch.setImageResource(UiTools.getResourceFromAttribute(getActivity(),
+                            R.attr.ic_playlist_on));
                 else
-                    mPlaylistSwitch.setImageResource(Util.getResourceFromAttribute(getActivity(),
-                                                     R.attr.ic_playlist));
-            }
-        });
-        mSongsList.setOnItemClickListener(new OnItemClickListener() {
-            @Override
-            public void onItemClick(AdapterView<?> av, View v, int p, long id) {
-                if (mService != null) {
-                    mService.playIndex(p);
-                }
-            }
-        });
-        mSongsList.setOnItemLongClickListener(new OnItemLongClickListener() {
-            @Override
-            public boolean onItemLongClick(AdapterView<?> parent, View view,
-                    int position, long id) {
-                getActivity().openContextMenu(view);
-                return true;
-            }
-        });
-        mSongsList.setOnItemDraggedListener(new AudioPlaylistView.OnItemDraggedListener() {
-            @Override
-            public void onItemDragged(int positionStart, int positionEnd) {
-                if (mService != null)
-                    mService.moveItem(positionStart, positionEnd);
-            }
-        });
-        mSongsList.setOnItemRemovedListener(new AudioPlaylistView.OnItemRemovedListener() {
-            @Override
-            public void onItemRemoved(int position) {
-                if (mService != null)
-                    mService.remove(position);
-                update();
+                    mPlaylistSwitch.setImageResource(UiTools.getResourceFromAttribute(getActivity(),
+                            R.attr.ic_playlist));
             }
         });
         registerForContextMenu(mSongsList);
@@ -285,29 +261,23 @@ public class AudioPlayer extends PlaybackServiceFragment implements PlaybackServ
         getView().cancelLongPress();
     }
 
-    @Override
-    public void onCreateContextMenu(ContextMenu menu, View v, ContextMenuInfo menuInfo) {
-        MenuInflater menuInflater = getActivity().getMenuInflater();
-        menuInflater.inflate(R.menu.audio_player, menu);
-    }
+    public void onPopupMenu(View anchor, final int position) {
+        PopupMenu popupMenu = new PopupMenu(getActivity(), anchor);
+        popupMenu.getMenuInflater().inflate(R.menu.audio_player, popupMenu.getMenu());
 
-    @Override
-    public boolean onContextItemSelected(MenuItem item) {
-        if (getUserVisibleHint() && item.getMenuInfo() instanceof AdapterContextMenuInfo) {
-            AdapterContextMenuInfo info = (AdapterContextMenuInfo) item.getMenuInfo();
-            if(info == null) // info can be null
-                return super.onContextItemSelected(item);
-            int id = item.getItemId();
-
-            if(id == R.id.audio_player_mini_remove) {
-                Log.d(TAG, "Context menu removing " + info.position);
-                if (mService != null)
-                    mService.remove(info.position);
-                return true;
+        popupMenu.setOnMenuItemClickListener(new PopupMenu.OnMenuItemClickListener() {
+            @Override
+            public boolean onMenuItemClick(MenuItem item) {
+                if(item.getItemId() == R.id.audio_player_mini_remove) {
+                    if (mService != null) {
+                        mService.remove(position);
+                        return true;
+                    }
+                }
+                return false;
             }
-            return super.onContextItemSelected(item);
-        } else
-            return false;
+        });
+        popupMenu.show();
     }
 
     /**
@@ -347,35 +317,35 @@ public class AudioPlayer extends PlaybackServiceFragment implements PlaybackServ
         mResumeToVideo.setVisibility(mService.getVideoTracksCount() > 0 ? View.VISIBLE : View.GONE);
 
         if (mService.isPlaying()) {
-            mPlayPause.setImageResource(Util.getResourceFromAttribute(act, R.attr.ic_pause));
+            mPlayPause.setImageResource(UiTools.getResourceFromAttribute(act, R.attr.ic_pause));
             mPlayPause.setContentDescription(getString(R.string.pause));
-            mHeaderPlayPause.setImageResource(Util.getResourceFromAttribute(act, R.attr.ic_pause));
+            mHeaderPlayPause.setImageResource(UiTools.getResourceFromAttribute(act, R.attr.ic_pause));
             mHeaderPlayPause.setContentDescription(getString(R.string.pause));
         } else {
-            mPlayPause.setImageResource(Util.getResourceFromAttribute(act, R.attr.ic_play));
+            mPlayPause.setImageResource(UiTools.getResourceFromAttribute(act, R.attr.ic_play));
             mPlayPause.setContentDescription(getString(R.string.play));
-            mHeaderPlayPause.setImageResource(Util.getResourceFromAttribute(act, R.attr.ic_play));
+            mHeaderPlayPause.setImageResource(UiTools.getResourceFromAttribute(act, R.attr.ic_play));
             mHeaderPlayPause.setContentDescription(getString(R.string.play));
         }
         if (mService.isShuffling()) {
-            mShuffle.setImageResource(Util.getResourceFromAttribute(act, R.attr.ic_shuffle_on));
+            mShuffle.setImageResource(UiTools.getResourceFromAttribute(act, R.attr.ic_shuffle_on));
             mShuffle.setContentDescription(getResources().getString(R.string.shuffle_on));
         } else {
-            mShuffle.setImageResource(Util.getResourceFromAttribute(act, R.attr.ic_shuffle));
+            mShuffle.setImageResource(UiTools.getResourceFromAttribute(act, R.attr.ic_shuffle));
             mShuffle.setContentDescription(getResources().getString(R.string.shuffle));
         }
         switch(mService.getRepeatType()) {
         case PlaybackService.REPEAT_NONE:
-            mRepeat.setImageResource(Util.getResourceFromAttribute(act, R.attr.ic_repeat));
+            mRepeat.setImageResource(UiTools.getResourceFromAttribute(act, R.attr.ic_repeat));
             mRepeat.setContentDescription(getResources().getString(R.string.repeat));
             break;
         case PlaybackService.REPEAT_ONE:
-            mRepeat.setImageResource(Util.getResourceFromAttribute(act, R.attr.ic_repeat_one));
+            mRepeat.setImageResource(UiTools.getResourceFromAttribute(act, R.attr.ic_repeat_one));
             mRepeat.setContentDescription(getResources().getString(R.string.repeat_single));
             break;
         default:
         case PlaybackService.REPEAT_ALL:
-            mRepeat.setImageResource(Util.getResourceFromAttribute(act, R.attr.ic_repeat_on));
+            mRepeat.setImageResource(UiTools.getResourceFromAttribute(act, R.attr.ic_repeat_on));
             mRepeat.setContentDescription(getResources().getString(R.string.repeat_all));
             break;
         }
@@ -407,8 +377,7 @@ public class AudioPlayer extends PlaybackServiceFragment implements PlaybackServ
     }
 
     @Override
-    public void onMediaEvent(Media.Event event) {
-    }
+    public void onMediaEvent(Media.Event event) {}
 
     @Override
     public void onMediaPlayerEvent(MediaPlayer.Event event) {
@@ -429,13 +398,13 @@ public class AudioPlayer extends PlaybackServiceFragment implements PlaybackServ
         }
     }
 
-    private void updateList() {
-        int currentIndex = -1;
+    public void updateList() {
+        int currentIndex = -1, oldCount = mPlaylistAdapter.getItemCount();
         if (mService == null)
             return;
 
-        final List<MediaWrapper> previousAudioList = mSongsListAdapter.getMedias();
-        mSongsListAdapter.clear();
+        final List<MediaWrapper> previousAudioList = mPlaylistAdapter.getMedias();
+        mPlaylistAdapter.clear();
 
         final List<MediaWrapper> audioList = mService.getMedias();
         final String currentItem = mService.getCurrentMediaLocation();
@@ -445,19 +414,22 @@ public class AudioPlayer extends PlaybackServiceFragment implements PlaybackServ
                 final MediaWrapper media = audioList.get(i);
                 if (currentItem != null && currentItem.equals(media.getLocation()))
                     currentIndex = i;
-                mSongsListAdapter.add(media);
+                mPlaylistAdapter.add(media);
             }
         }
-        mSongsListAdapter.setCurrentIndex(currentIndex);
-
-        mSongsListAdapter.notifyDataSetChanged();
+        mPlaylistAdapter.setCurrentIndex(currentIndex);
+        int count = mPlaylistAdapter.getItemCount();
+        if (oldCount != count)
+            mPlaylistAdapter.notifyDataSetChanged();
+        else
+            mPlaylistAdapter.notifyItemRangeChanged(0, count);
 
         final int selectionIndex = currentIndex;
         if (!previousAudioList.equals(audioList))
             mSongsList.post(new Runnable() {
                 @Override
                 public void run() {
-                    mSongsList.setSelection(selectionIndex);
+                    mPlaylistAdapter.setCurrentIndex(selectionIndex);
                 }
             });
     }
@@ -682,6 +654,7 @@ public class AudioPlayer extends PlaybackServiceFragment implements PlaybackServ
     public void onConnected(PlaybackService service) {
         super.onConnected(service);
         mService.addCallback(this);
+        mPlaylistAdapter.setService(service);
         update();
     }
 
@@ -707,6 +680,8 @@ public class AudioPlayer extends PlaybackServiceFragment implements PlaybackServ
 
         int possibleSeek;
         boolean vibrated;
+
+        @RequiresPermission(Manifest.permission.VIBRATE)
         Runnable seekRunnable = new Runnable() {
             @Override
             public void run() {
