@@ -28,11 +28,10 @@ import android.net.Uri;
 import android.os.Build;
 import android.os.Bundle;
 import android.os.Message;
+import android.support.design.widget.Snackbar;
 import android.support.v4.app.Fragment;
 import android.support.v4.app.FragmentTransaction;
-import android.support.v7.app.AlertDialog;
 import android.support.v7.widget.LinearLayoutManager;
-import android.support.v7.widget.PopupMenu;
 import android.support.v7.widget.RecyclerView;
 import android.text.TextUtils;
 import android.util.SparseArray;
@@ -46,23 +45,21 @@ import android.view.ViewGroup;
 import android.widget.TextView;
 
 import org.videolan.libvlc.Media;
-import org.videolan.libvlc.util.AndroidUtil;
 import org.videolan.libvlc.util.MediaBrowser;
-import org.videolan.vlc.MediaWrapper;
 import org.videolan.vlc.R;
 import org.videolan.vlc.VLCApplication;
-import org.videolan.vlc.gui.DividerItemDecoration;
 import org.videolan.vlc.gui.MainActivity;
 import org.videolan.vlc.gui.SecondaryActivity;
-import org.videolan.vlc.gui.dialogs.CommonDialogs;
 import org.videolan.vlc.gui.video.VideoPlayerActivity;
+import org.videolan.vlc.gui.view.ContextMenuRecyclerView;
+import org.videolan.vlc.gui.view.DividerItemDecoration;
+import org.videolan.vlc.gui.view.SwipeRefreshLayout;
 import org.videolan.vlc.interfaces.IRefreshable;
-import org.videolan.vlc.util.Util;
+import org.videolan.vlc.media.MediaUtils;
+import org.videolan.vlc.media.MediaWrapper;
+import org.videolan.vlc.util.FileUtils;
 import org.videolan.vlc.util.VLCInstance;
-import org.videolan.vlc.util.VLCRunnable;
 import org.videolan.vlc.util.WeakHandler;
-import org.videolan.vlc.widget.ContextMenuRecyclerView;
-import org.videolan.vlc.widget.SwipeRefreshLayout;
 
 import java.util.ArrayList;
 
@@ -313,10 +310,20 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
     }
 
 
+    View.OnClickListener mCancelDeleteMediaListener = new View.OnClickListener() {
+        @Override
+        public void onClick(View view) {
+            mHandler.removeMessages(BrowserFragmentHandler.MSG_DELETE_MEDIA);
+        }
+    };
+
+
     protected static class BrowserFragmentHandler extends WeakHandler<BaseBrowserFragment> {
 
         public static final int MSG_SHOW_LOADING = 0;
         public static final int MSG_HIDE_LOADING = 1;
+        public static final int MSG_DELETE_MEDIA = 2;
+        public static final int MSG_REFRESH = 3;
 
         public BrowserFragmentHandler(BaseBrowserFragment owner) {
             super(owner);
@@ -332,6 +339,17 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
                     removeMessages(MSG_SHOW_LOADING);
                     fragment.mSwipeRefreshLayout.setRefreshing(false);
                     break;
+                case MSG_DELETE_MEDIA:
+                    FileUtils.asyncRecursiveDelete((String) msg.obj, new FileUtils.Callback() {
+                        @Override
+                        public void onResult(boolean success) {
+                            obtainMessage(MSG_REFRESH).sendToTarget();
+                        }
+                    });
+                    break;
+                case MSG_REFRESH:
+                    if (getOwner() != null && !getOwner().isDetached())
+                        getOwner().refresh();
             }
         }
     }
@@ -359,7 +377,7 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
 
     protected void setContextMenu(MenuInflater inflater, Menu menu, int position) {
         MediaWrapper mw = (MediaWrapper) mAdapter.getItem(position);
-        boolean canWrite = Util.canWrite(mw.getLocation());
+        boolean canWrite = this instanceof FileBrowserFragment && FileUtils.canWrite(mw.getUri().getPath());
         boolean isAudio = mw.getType() == MediaWrapper.TYPE_AUDIO;
         boolean isVideo = mw.getType() == MediaWrapper.TYPE_VIDEO;
         if (isAudio || isVideo) {
@@ -394,22 +412,8 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
     }
 
     @TargetApi(Build.VERSION_CODES.HONEYCOMB)
-    public void onPopupMenu(View anchor, final int position) {
-        if (!AndroidUtil.isHoneycombOrLater()) {
-            // Call the "classic" context menu
-            anchor.performLongClick();
-            return;
-        }
-        PopupMenu popupMenu = new PopupMenu(getActivity(), anchor);
-        setContextMenu(popupMenu.getMenuInflater(), popupMenu.getMenu(), position);
-
-        popupMenu.setOnMenuItemClickListener(new PopupMenu.OnMenuItemClickListener() {
-            @Override
-            public boolean onMenuItemClick(MenuItem item) {
-                return handleContextItemSelected(item, position);
-            }
-        });
-        popupMenu.show();
+    public void openContextMenu(final int position) {
+        mRecyclerView.openContextMenu(position);
     }
 
     protected boolean handleContextItemSelected(MenuItem item, int position) {
@@ -420,7 +424,7 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
         switch (id){
             case R.id.directory_view_play:
                 mw.removeFlags(MediaWrapper.MEDIA_FORCE_AUDIO);
-                Util.openMedia(getActivity(), mw);
+                MediaUtils.openMedia(getActivity(), mw);
                 return true;
             case R.id.directory_view_append: {
                 if (mService != null)
@@ -428,15 +432,11 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
                 return true;
             }
             case R.id.directory_view_delete:
-                AlertDialog alertDialog = CommonDialogs.deleteMedia(
-                        mw.getType(), getActivity(), mw.getLocation(),
-                        new VLCRunnable() {
-                            @Override
-                            public void run(Object o) {
-                                refresh();
-                            }
-                        });
-                alertDialog.show();
+                Snackbar.make(getView(), getString(R.string.file_deleted), Snackbar.LENGTH_LONG)
+                        .setAction(android.R.string.cancel, mCancelDeleteMediaListener)
+                        .show();
+                Message msg = mHandler.obtainMessage(BrowserFragmentHandler.MSG_DELETE_MEDIA, mw.getUri().getPath());
+                mHandler.sendMessageDelayed(msg, 3000);
                 return true;
             case  R.id.directory_view_info:
                 Intent i = new Intent(getActivity(), SecondaryActivity.class);
@@ -460,7 +460,7 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
                     if (mediaItem.getType() == MediaWrapper.TYPE_AUDIO || mediaItem.getType() == MediaWrapper.TYPE_VIDEO)
                         mediaList.add(mediaItem);
                 }
-                Util.openList(getActivity(), mediaList, 0);
+                MediaUtils.openList(getActivity(), mediaList, 0);
                 return true;
 //            case R.id.directory_view_hide_media:
 //                try {
