@@ -45,7 +45,7 @@ import java.util.List;
 import java.util.StringTokenizer;
 
 public class AndroidDevices {
-    public final static String TAG = "VLC/Util/AndroidDevices";
+    public final static String TAG = "VLC/UiTools/AndroidDevices";
     public final static String EXTERNAL_PUBLIC_DIRECTORY = Environment.getExternalStorageDirectory().getPath();
 
     final static boolean hasNavBar;
@@ -66,24 +66,25 @@ public class AndroidDevices {
         return Environment.getExternalStorageState().equals(Environment.MEDIA_MOUNTED);
     }
 
-    public static boolean hasNavBar()
-    {
+    public static boolean hasNavBar() {
         return hasNavBar;
     }
 
-    /** hasCombBar test if device has Combined Bar : only for tablet with Honeycomb or ICS */
+    /**
+     * hasCombBar test if device has Combined Bar : only for tablet with Honeycomb or ICS
+     */
     public static boolean hasCombBar() {
         return (!AndroidDevices.isPhone()
                 && ((VERSION.SDK_INT >= VERSION_CODES.HONEYCOMB) &&
-                    (VERSION.SDK_INT <= VERSION_CODES.JELLY_BEAN)));
+                (VERSION.SDK_INT <= VERSION_CODES.JELLY_BEAN)));
     }
 
-    public static boolean isPhone(){
-        TelephonyManager manager = (TelephonyManager)VLCApplication.getAppContext().getSystemService(Context.TELEPHONY_SERVICE);
+    public static boolean isPhone() {
+        TelephonyManager manager = (TelephonyManager) VLCApplication.getAppContext().getSystemService(Context.TELEPHONY_SERVICE);
         return manager.getPhoneType() != TelephonyManager.PHONE_TYPE_NONE;
     }
 
-    public static boolean hasTsp(){
+    public static boolean hasTsp() {
         return hasTsp;
     }
 
@@ -94,7 +95,7 @@ public class AndroidDevices {
 
         List<String> typeWL = Arrays.asList("vfat", "exfat", "sdcardfs", "fuse", "ntfs", "fat32", "ext3", "ext4", "esdfs");
         List<String> typeBL = Arrays.asList("tmpfs");
-        String[] mountWL = { "/mnt", "/Removable", "/storage" };
+        String[] mountWL = {"/mnt", "/Removable", "/storage"};
         String[] mountBL = {
                 "/mnt/secure",
                 "/mnt/shell",
@@ -102,16 +103,16 @@ public class AndroidDevices {
                 "/mnt/obb",
                 "/mnt/media_rw/extSdCard",
                 "/mnt/media_rw/sdcard",
-                "/storage/emulated" };
+                "/storage/emulated"};
         String[] deviceWL = {
                 "/dev/block/vold",
                 "/dev/fuse",
-                "/mnt/media_rw" };
+                "/mnt/media_rw"};
 
         try {
             bufReader = new BufferedReader(new FileReader("/proc/mounts"));
             String line;
-            while((line = bufReader.readLine()) != null) {
+            while ((line = bufReader.readLine()) != null) {
 
                 StringTokenizer tokens = new StringTokenizer(line, " ");
                 String device = tokens.nextToken();
@@ -124,16 +125,15 @@ public class AndroidDevices {
 
                 // check that device is in whitelist, and either type or mountpoint is in a whitelist
                 if (Strings.startsWith(deviceWL, device) && (typeWL.contains(type) || Strings.startsWith(mountWL, mountpoint))) {
-                    int position = Strings.containsName(list, Strings.getName(mountpoint));
+                    int position = Strings.containsName(list, FileUtils.getFileNameFromPath(mountpoint));
                     if (position > -1)
                         list.remove(position);
                     list.add(mountpoint);
                 }
             }
-        }
-        catch (FileNotFoundException e) {}
-        catch (IOException e) {}
-        finally {
+        } catch (FileNotFoundException e) {
+        } catch (IOException e) {
+        } finally {
             Util.close(bufReader);
         }
         return list;
@@ -148,7 +148,7 @@ public class AndroidDevices {
 
     @TargetApi(VERSION_CODES.HONEYCOMB_MR1)
     public static float getCenteredAxis(MotionEvent event,
-            InputDevice device, int axis) {
+                                        InputDevice device, int axis) {
         final InputDevice.MotionRange range =
                 device.getMotionRange(axis, event.getSource());
 
@@ -168,9 +168,9 @@ public class AndroidDevices {
         return 0;
     }
 
-    public static boolean hasLANConnection(){
+    public static boolean hasLANConnection() {
         boolean networkEnabled = false;
-        ConnectivityManager connectivity = (ConnectivityManager)(VLCApplication.getAppContext().getSystemService(Context.CONNECTIVITY_SERVICE));
+        ConnectivityManager connectivity = (ConnectivityManager) (VLCApplication.getAppContext().getSystemService(Context.CONNECTIVITY_SERVICE));
         if (connectivity != null) {
             NetworkInfo networkInfo = connectivity.getActiveNetworkInfo();
             if (networkInfo != null && networkInfo.isConnected() &&
@@ -179,6 +179,5 @@ public class AndroidDevices {
             }
         }
         return networkEnabled;
-
     }
 }
